.. Nebari API documentation documentation master file, created by
   sphinx-quickstart on Fri Mar 10 12:28:01 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Nebari API documentation's documentation!
====================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. toctree::
   cli

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
